%global __requires_exclude devel\\\(libogdi31.*\\\)|devel\\\(libcfitsio.*\\\)|libgrass

# We don't want to provide private Python extension libs
%global __provides_exclude_from ^%{python3_sitearch}/.*\.so$

%define major          34
%define libname        %mklibname %{name} %{major}
%define libnamedev     %mklibname %{name} -d

%define ogdidir %{_includedir}
%define ogdidir %{_includedir}/ogdi

Name:           gdal
Version:        3.8.5
Release:        %mkrel 1
Summary:        The Geospatial Data Abstraction Library (GDAL)
Group:          Sciences/Geosciences
License:        MIT
URL:            https://www.gdal.org/

%(if [ ! -f %_sourcedir/%{name}-%{version}.tar.xz ]; then cd %_sourcedir/ && wget  https://download.osgeo.org/gdal/%{version}/%{name}-%{version}.tar.xz; fi)
Source0:        https://download.osgeo.org/gdal/%{version}/%{name}-%{version}.tar.xz

BuildRequires: lib64cfitsio-devel
BuildRequires: lib64cryptopp6-devel
BuildRequires: lib64curl-devel
BuildRequires: lib64expat-devel
BuildRequires: freexl-devel
BuildRequires: lib64geos-devel
BuildRequires: lib64geotiff-devel
BuildRequires: lib64gif-devel
BuildRequires: lib64hdf5-devel
BuildRequires: lib64jasper-devel
BuildRequires: lib64jpeg-devel
BuildRequires: lib64json-devel
BuildRequires: lib64jxl-devel
BuildRequires: lib64lzma-devel
BuildRequires: lib64mariadb-devel
BuildRequires: lib64netcdf-devel 
BuildRequires: lib64ogdi-devel
BuildRequires: lib64openjpeg-devel
BuildRequires: lib64openexr-devel
BuildRequires: lib64opencl-devel
BuildRequires: lib64ogdi-devel
BuildRequires: lib64pcre0-devel
BuildRequires: lib64png1.6-devel 
BuildRequires: lib64poppler-devel
BuildRequires: lib64proj-devel 
BuildRequires: lib64python3-devel
BuildRequires: lib64qhull-devel 
BuildRequires: lib64sqlite3-devel
BuildRequires: lib64tiff-devel
BuildRequires: lib64unixODBC-devel
BuildRequires: lib64webp-devel
BuildRequires: lib64xerces-c-devel
BuildRequires: lib64xml2-devel
BuildRequires: lib64tirpc-devel
BuildRequires: libspatialite-devel
BuildRequires: libstdc++-devel
BuildRequires: librx-devel
BuildRequires: swig
BuildRequires: lib64zstd-devel
BuildRequires: postgresql13-devel
BuildRequires: zlib1-devel
BuildRequires: python3-numpy-devel
BuildRequires: python3-setuptools
BuildRequires: lib64g2clib-devel
BuildRequires: bash-completion
BuildRequires: doxygen
BuildRequires:	gettext-devel

Obsoletes:    lib64gdal29
Obsoletes:    lib64gdal30
Obsoletes:    lib64gdal31
Obsoletes:    lib64gdal32
Obsoletes:    lib64gdal33

%description
The Geospatial Data Abstraction Library (GDAL) is a unifying
C/C++ API for accessing raster geospatial data, and currently
includes formats like GeoTIFF, Erdas Imagine, Arc/Info
Binary, CEOS, DTED, GXF, and SDTS. It is intended to provide
efficient access, suitable for use in viewer applications,
and also attempts to preserve coordinate systems and metadata.
Python, C, and C++ interfaces are available.

%package plugins
Summary:        Drivers information for GDAL library
Group:          Sciences/Geosciences

%description plugins
Drivers information for GDAL library.


%package -n     python3-gdal
Summary:        The Python 3 bindings for the GDAL library
Group:          Sciences/Geosciences
Requires:       python3-numpy
Provides:       python3-gdal = %{version}-%{release}
Obsoletes:      python-gdal
Provides:       python-gdal = %{version}-%{release}
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-breathe

%description -n python3-gdal
The Python 3 bindings for the GDAL library.

%package -n     %{libname}
Summary:        Libraries required for the GDAL library
Group:          System/Libraries
Provides:       lib%{name} = %{version}
Requires:       gdal-plugins >= %{version}-%{release}
Obsoletes:    lib64gdal29
Obsoletes:    lib64gdal30
Obsoletes:    lib64gdal31
Obsoletes:    lib64gdal32
Obsoletes:    lib64gdal33

%description -n %{libname}
Libraries required for the GDAL library.

%package -n     %{libnamedev}
Summary:        Development files for using the GDAL library
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}
Provides:       %{name}-devel = %{version}


%description -n %{libnamedev}
Development files for using the GDAL library.

%prep
%autosetup -p1
sed -i 's|libdir=\${exec_prefix}/lib|libdir=\${exec_prefix}/%{_lib}|' cmake/template/gdal.pc.in

%build
%cmake \
   -DENABLE_GDAL_PLUGINS:BOOL=ON \
   -DGDAL_USE_OPENCL:BOOL=ON
%cmake_build

%install
%cmake_install
find %{buildroot} -name '*.la' -delete


%files
%doc NEWS.md VERSION
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/%{name}/
%{_datadir}/bash-completion/completions/*
%exclude %{_bindir}/gdal-config
%exclude %{_mandir}/man1/gdal-config.1*

%files plugins
%{_libdir}/gdalplugins/

%files -n %{libnamedev}
%{_bindir}/%{name}-config
%{_mandir}/man1/%{name}-config.1*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/gdal
%{_includedir}/*.h

%files -n %{libname}
%{_libdir}/*.so.%{major}*
%{_datadir}/java/gdal*
%{_libdir}/jni/libgdalalljni.so

%files -n python3-gdal
%doc swig/python/README.rst
%{python3_sitearch}/*


%changelog
* Fri Apr 05 2024 pp <pp> 3.8.5-1pclos2024
- new version

* Tue Mar 05 2024 pp <pp> 3.8.4-2pclos2024
- rebuild against new proj

* Mon Feb 19 2024 pp <pp> 3.8.4-1pclos2024
- new version

* Tue Jan 10 2024 pp <pp> 3.8.3-1pclos2024
- new version

* Thu Dec 28 2023 pp <pp> 3.8.2-2pclos2024
- remove conflicts in plugins package

* Wed Dec 27 2023 pp <pp> 3.8.2-1pclos2024
- new version with new lib major 34

* Wed Nov 29 2023 pp <pp> 3.7.3-2pclos2023
- rebuild against new spatialite

* Mon Nov 06 2023 pp <pp> 3.7.3-1pclos2023
- new version

* Fri Sep 15 2023 pp <pp> 3.7.2-1pclos2023
- new version

* Fri Jul 14 2023 pp <pp> 3.7.1-1pclos2023
- new version

* Wed May 17 2023 pp <pp> 3.7.0-2pclos2023
- obsoleted older gdal libs

* Thu May 11 2023 pp <pp> 3.7.0-1pclos2023
- new version

* Sat Apr 22 2023 pp <pp> 3.6.4-1pclos2023
- new version

* Wed Mar 15 2023 pp <pp> 3.6.3-1pclos2023
- new version

* Thu Jan 05 2023 pp <pp> 3.6.2-1pclos2023
- new version

* Thu Dec 29 2022 pp <pp> 3.6.1-2pclos2022
- remove grass shit

* Fri Dec 16 2022 pp <pp> 3.6.1-1pclos2022
- new version

